@@ -2,7 +2,6 @@ package Test::Sweet::Keyword::Test;
 use strict;
 use warnings;
 
-use Devel::BeginLift;
 use Devel::Declare ();
 use Sub::Name;
 
@@ -24,23 +23,29 @@ sub install_methodhandler {
     );
 }
 
+sub parse_proto {
+    my ($self, $proto) = @_;
+    # todo: warn about bad syntax
+    return [ grep { /[A-Za-z]+/} split /[^:_A-Za-z0-9+]+/, $proto ];
+}
+
 sub parser {
     my $self = shift;
     $self->init(@_);
 
     $self->skip_declarator;
     my $name = $self->strip_name;
-    $self->strip_proto;
-    $self->strip_attrs;
-    #$self->parse_proto($proto);
+    my $raw_proto = $self->strip_proto || '';
+    my $attrs = $self->strip_attrs || '';
+    my $requested_traits = $self->parse_proto($raw_proto . ' '. $attrs); # why not let attrs be used too?
 
     my $inject = $self->scope_injector_call();
-    $self->inject_if_block($inject. " my \$self = shift; ");
+    $self->inject_if_block($inject. " my \$self = shift; my \$test = shift; ");
 
     my $pack = Devel::Declare::get_curstash_name;
     Devel::Declare::shadow_sub("${pack}::test", sub (&) {
         my $test_method = shift;
-        $pack->meta->add_test( $name, $test_method );
+        $pack->meta->add_test( $name, $test_method, $requested_traits );
     });
 
     return;
